bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 16. Aventiure
___________________________________________________ #### <Wie Sifrit erslagen wart>
| ### vnther vnd Hagne die reken vil balt ### lobeten mit vntriwen ein pirsen in den walt ### mit ir scharpfen geren si wolden iagen swin ### beren vnd wisende was kvnde kveners gesin ### Da mite reit ovch Sifrit in erlichem site ### maniger hande spise die fuorte man in mite ### zuo eime kalten brunnen verlos er sid den lip ### daz hete geraten Prvnhilt kvnich Gvnthers wip
###### 861 | ### Do gie der degen kuone da er Kriemhilde vant ### do was nu ovf gesovmet sin <edel> piresgewant ### vnd ovch der gesellen si wolden vber Rin ### do endorfte Kriemhilde nimmer leider gesin
###### 862 | ### Sine trûtinne kvst er an den mvnt ### got laze mich dich vrovwe gesehen noch gesvnt ### vnd mich ovch diniv ovgen mit holden magen din ### solt dv kurzwilen ich mach heime niht gesin
###### 863 | ### Do dahte si an div mære si entorste ir niht sagen ### div si Hagnen seite do begvnde si clagen ### div edel kvniginne daz si üe gewan den lip ### do weinde ane maze daz vil wunderschoene wip
###### 864 | ### Si sprach zuo dem reken lat iwer iagen sin ### mir trovmte heint leide wie iuch zwei wildiv swin ### iageten vber heide da wurden bluomen rot ### daz ich so sere weine daz get mir werliche not
###### 865 | ### Ich fvrhte harte sere etelichen rat ### obe man der deheinen missedient hat ### die vns fuegen kvnnen vientlichen haz ### belibet lieber herre mit triwen rate ich iv daz
###### 866 | ### Min liebiv truttinne ich kvme in kurzen tagen ### ich weiz hie niht der livte die mir iht hazzes tragen ### alle dine mage sint mir gemeine holt ### ovch han ich an den degnen hie niht anders versolt
###### 867 | ### Neina herre Sifrit ia furht ich dinen val ### mir trovmte heint leide wie obe dir zetal ### vielen zwene berge ich gesach dich nimmer me ### wil dv von mir scheiden daz tuot mir innerclichen we
###### 868 | ### Er vmbevie mit armen daz tugentriche wip ### mit minneclichem kvsse er trute ir schoenen lip ### mit urlovbe er dannen schiet in kurzer stvnt ### si gesach in leider darnach nimmer mer gesvnt
###### 869 | ### Do riten si von dannen in einem tiefen walt ### durch chvrzewile willen vil manich riter balt ### volgeten Gvnthere vnd Sifride dan ### Gernot vnde Giselher die wolden deheime bestan
###### 870 | ### Geladen vil der rosse kom vor in vber Rin ### div den ieictgesellen truogen brot vnde win ### vleisch mit den vischen vnde ander manigen rat [36a] ### den ein kvnich <so> rike harte billichen hat
###### 871 | ### Si hiezen herbergen fur den gruonen walt ### gen des wildes abelaufe die stolzen iægeren balt ### da si da iagen solden vf einen wert vil breit ### do was ovch komen Sifrit daz wart dem kvnige geseit
###### 872 | ### Von den ieitgesellen wrden do bestan ### die warte an allen ende do sprach der kuene man ### Sifrit der vil starke wer sol vns in den walt ### wisen nach den wilde ir degne kvene vnde balt
###### 873 | ### Wellen wir vns scheiden sprach do Hagne ### ê daz wir hie beginnen hie ze iagene ### da bi mvgen bekennen ich vnd die herren min ### wer die besten iægere an diser waltræise sin
###### 874 | ### Lvte vnde hvnde solen wir teilen gar ### so chere islicher da er gerne var ### der danne iage beste der sol des haben danch ### der iæger biten wart niht lange bi an ander
###### 875 | ### Do sprach der herre Sifrit ich han der hvnde rat ### wan einen braken der so genozzen hat ### daz er die verte erkenne der tiere durch den tan ### wir komen wol ce zeide sprach der Kriemhilde man
###### 876 | ### Do nam ein alter iægere einen spurhvnt ### er brahte den herren in einer kvrzer stvnt ### da si vil tiere fvnden swaz der von leger stuont ### div <erieiten> die gesellen so noch guote ieger tuont
###### 877 | ### Swaz ir der brake erspranchte div slvoc mit siner hant ### Sifrit der kuone der helt von Niderlant ### sin ros lief so sere daz ir im niht entran ### den lop er vor in allen an dem geieide gewan
###### 878 | ### Er was an allen dingen biderbe genvoc ### sin tier daz erste daz er ze tode sluoc ### was ein starkes halpswuol mit der siner hant ### da nach er vil schiere ein vngefuegen lewen vant
###### 879 | ### Der brake den erspranchte er schoz in mit den bogen ### ein scharfestrale hete erin gezogen ### der lewe lief nach dem schuzze wan drier sprunge lanc ### sine ieitgesellen seiten Sifride danch
###### 880 | ### Darnach sluoc er schiere einen wisent vn– einen elch ### starker ovre viere vnd einen grimmen schelch ### sin ros truoch in so balde daz im niht entran ### hirze oder hinde kvnd im wenich enkan
###### 881 | ### Einen eber grozen vant der spurhunt ### als er begvnde vliehen do kom an der stunt ### des geieides meister er bestuont in vf der sla ### daz swin zornechlichen lief an den kuenen degen sa
###### 882 | ### Do sluoc in mit dem swerte Kriemhilde man ### ez hete ein ander iegere so sanfte niht getan ### do ern hete eruellet man vie den spurhvnt ### do wart sin rich geieide allen Bvrgonden kvnt
###### 883 | ### Si horten allenthalben ludem vnde doz [36b] ### von lûten vnd von hunden der schal was so groz ### daz in da von antwurtete der berch vnd ovch der tan ### vier vnde zweinzech ruore die ieger heten verlan
###### 884 | ### Do mvosen vil der tiere verliesen da daz leben ### do wanden si fuegen daz man solde geben ### in den pris des ieides des kvnde niht geschehen ### do der starke Sifrit wart zer viwerstat gesehen
###### 885 | ### Daz ieit was ergangen vnde doch nih gar ### die <zer> wiwerstat wolden die brahten mit in dar ### vil maniger tiere hovte vnd wildes genvoch ### hei waz man ce kuchen daz ingesinde truoch
###### 886 | ### Do hiez der kvnich kvnden den iægern wol geborn ### daz er inbizen wolde do wart lûte ein horn ### zeiner stvnt geblasen da mite wart bekant ### daz man den fvrsten edel cen herbergen vant
###### 887 | ### Do sprach der herre Sifrit nv rovmen wir den tan ### sin ros truoch in ebene si ilten mit im dan ### si erspranchten mit ir schalle ein tier gemehelich ### einen beren wilden do spranch der degen hinder sich
###### 888 | ### Ich wil vns hergesellen kvrzwile weren ### ir svlt den braken lazen ich sihe einen bern ### der sol mit vns hinnen zen herbergen varn ### er fliehe danne sere er kan sichs nimmer bewarn
###### 889 | ### Der brake wart verlazen der bere spranch von dan ### do wolden in erriten Kriemhilde man ### er kom in ein geuelle do kund ez niht wesen ### daz starke tier do wande vor den iægeren genesen
###### 890 | ### Do spranch von sime rosse der stolze riter guot ### er begvnde nach lovfen daz tier was vnbehuot ### ez kvnd im niht entrinnen do vie erz sa cehant ### an alle wunden der helt ez schiere gebant
###### 891 | ### Kracen noch gebizen kvnd ez niht den man ### er band ez zvo dem satele vf saz der snelle san ### er braht ez an die viwerstat durch sinen hohen muot ### zeiner kurzwile der degen kuene vn– guot
###### 892 | ### Wie rehte herlichen er ze herbergen reit ### sin ger was vil michel strach vnde breit ### im hie ein cier wafen nider vf den sporn ### von rotem golde der herre fuorte ein <schone> horn
###### 893 | ### Von bezzerm prisgewæte hort ich nie gesagen ### einen roch <swartz> pfhellin sach man in tragen ### vnd einen huot von zodele der rike was genvoch ### hei was er borten an sime kochere truoch
###### 894 | ### Von eime pantel was daruber <gezogen> ### ein hovt durch die sueze ovch fuerte er einen bogen ### den man mit antwerke mvose ciehen dan ### der in spannen wolde ern hetez selbe getan
###### 895 | ### Von einer ludmes hûte was allez sin gewant ### von hovbet unz anz ende gestrovt man durfe vant ### vz der liehten ruhe vil manich goldes zein [37a] ### ze beiden siten dem kuenen iegermeister schein
###### 896 | ### Ovch fuort er Balmvngen ein ciere wafen breit ### daz was also scherphe daz ez nie vermeit ### swa manz sluoch vf helme sin eke waren guot ### der herliche iegere was vil hohe gemvot
###### 897 | ### Sid ich iv div mere gar bescheiden sol ### im was sin edel kocher guoter strale vol ### von gvldinen tullen div sahs wol hende breit ### ez muoste balde ersterben swaz er da mit versneit
###### 898 | ### Do reit der riter edel vil weidenliche dan ### in sahen zuo in komende Gvnthers man ### si liefen im enkegne vnd enphiengen im daz march ### do fuorte er bi dem satele den bern groz vnde starch
###### 899 | ### Als er gestuont von rosse do loste er im div bant ### von fueze vnd ovch von mvnde do erlute sa zehant ### vil luote daz gehvnde swaz ez den bern sach ### daz tier ze walde wolde des heten die lûte vngemach
###### 900 | ### Der bere von dem schalle durch die kuche geriet ### hey waz er kvken knehte von dem viwer schiet ### vil kezzele wart geruot cerfuort manich brant ### hei waz man guoter spise in dem asche ligen vant
###### 901 | ### Do sprvngen von dem sedele die herren vnd ir man ### der bere begvnde zvrnen der kvnich hiez do lan ### allez daz gehvnde daz an seilen lac ### vnd wer ez wol verendet si heten vroelichen tac
###### 902 | ### Mit bogen vnd mit spiezen niht langer man daz lie ### dar liefen do die snellen da der bere gie ### do was so vil der hvnde daz da nieman schoz ### von des livtes schalle daz gebirge allez erdoz
###### 903 | ### Der ber begvnde vliehen vor den hvnden dan ### im kvnde niht geuolgen wan Kriemhilde man ### er erlief in mit dem swerte ce tode er in do sluoch ### hin wider zuo dem viwre man den beren truoch
###### 904 | ### Do sprachen die daz sahen er wer ein kreftich man ### die stolcen ieitgesellen hiez man ze tische gan ### vf einen <schonen> anger saz ir da genuoc ### hei waz man riterspise den stolcen iegern do truoc
###### 905 | ### Die senchen komen seine die tragen solden win ### ez kvnde baz gedienet nimmer helden sin ### heten si darunder niht so valsem muot ### so waren wol die reken vor allen schanden behuot
###### 906 | ### Do sprach der herre Sifrit wunder mich des hat ### sid man vns von kuchen git so manigen rat ### warumbe vns die schenken darzvo niht bringen win ### man pflege baz der iegern ich wil niht ieitgeselle sin
###### 907 | ### Ich hete wol verdienet daz man min mæme ware ### der kvnich von denm tische spranch in valsche dare ### man sol iv gerne buezen swes wir gebresten han ### ez ist von Hagnen schvlden der wil vns erdursten lan
###### 908 | ### Do sprach von Trony Hagne lieber herre min [37b] ### ich wande daz pirsen hivte solde sin ### da ze dem Spetharte den win den sand ich dar ### sin wir hivte vngetrvnken wie wol ich mere daz bewar
###### 909 | ### Do sprach der Niderlende ir lip der habe undanch ### man solde mir siben sovme mit met vn– lutertranch ### haben her gefueret do des niht mohte sin ### do solde man vns gesidelet haben nahen an den Rin
###### 910 | ### Do sprach von Troni Hagne ir edelen riter balt ### ich weiz hie vil nahen einen brvnnen kalt ### daz ir niht erzurnet da sul wir hine gan ### der rat wart manigem degne ce grozen sorgen getan
###### 911 | ### Sifriden den reken twanch des durstes not ### den tisch er dester ziter ruken da gebot ### er wolde fur die berge zvo dem brvnnen gan ### do was der rat mit meine von den reken getan
###### 912 | ### Div tier hiez man vf wægnen vn– fuorn in daz lant ### div da hete verhovwen Sifrides hant ### man iach im grozer ern swer ez ie gesach ### Hagne sine triwe sere an Sifride brach
###### 913 | ### Do si wolden dannen zuo der linden breit ### do sprach von Trony Hagne mir ist des vil geseit ### daz niht gevolgen kvnde dem Kriemhilde man ### swenner welle gahen wold er vns daz sehen lan
###### 914 | ### Do sprach von Niderlande der kuene Sifrit ### daz mvget ir wol versuochen welt ir mir volgen mit ### ze wette zvo dem brvnnen so daz ist getan ### man <iehe> den gewinnes den man siht gewivnen han
###### 915 | ### Nv welle ovch wirz versuochen sprach Hagne der degen ### do sprach der starke Sifrit so wil ich mich legen ### fur iwer fueze nider an daz gras ### do er daz gehorte wie liep daz Gvnthers was
###### 916 | ### Do sprach der degen kuene ich wil iv mere sagen ### allez min gewete wil ich müt mir tragen ### den ger zuo dem schilde vnd min pirsgewant ### den kocher zvo dem swerte schier er vmbe gebant
###### 917 | ### Do zvgen si div kleider von dem libe dan ### in zwein wizen hemden sach man si beide stan ### sam zvai wildiv panthel si liefen durch den chle ### doch sah man bi den brvnnen den kuenen Sifriden ê
###### 918 | ### Den bris von allen dingen truoch er vor manigem man ### daz swert lost er schiere den kocher leit er dan ### den starken ger er leinde an der linden ast ### bi des brvnnen fluzze stuont der herliche gast
###### 919 | ### Die Sifrides tvgende waren harte groz ### den schilt er leite nider da der brunne floz ### swie harte so in durste der helt doch niht tranc ### ê der kvnich getrunke des seit er im vil bosen danc
###### 920 | ### Der brunne was kuele luoter vn– guot ### Gvnther si do neigte nider zuo der vluot ### als er hete getrvnken do rihtete er sic von dan [38a] ### alsam het ovch gerne der kuene Sifrit getan
###### 921 | ### Do engalt er siner zvhte den bogen vnd daz swert ### daz truoch allez Hagne von im danwert ### vn– spranch da hin widere da er den gere vant ### er sach nach einem bilde an des kuenen gewant
###### 922 | ### Do der herre Sifrit ob dem brunnen tranch ### er schoz im durch daz crivze daz von der wnden spranc ### daz bluot von dem herzen vaste an Hagnen wat ### solher missewende ein helt nv nimmer begat
###### 923 | ### Den ger im gen dem herzen steken er do lie ### also grimmecliche ce fluhte Hagne <nie> ### gelief in der werlde vor deheinem man ### do sich der starke Sifrit der grozen wunden versan
###### 924 | ### der herre tobelichen von dem brunnen spranch ### im ragete von den herten ein gerstange lanch ### der furste wande vinden bogen oder swert ### so mvoste wesen Hagne nach sime dienste gewert
###### 925 | ### Do der sere wnde des swertes niht vant ### do het et er niht mere wan des schildes rant ### er zuct in von dem brunnen do lief er Hagnen an ### do kvnd im niht entrinnen des kvnich Gvnthers man
###### 926 | ### Swie wunt er was zem tode so kreftechlich er sluoc ### daz vzer dem schilde drate genuoch ### des edelen gesteines der schilt vil gar zerbrast ### sich hete gerne errochen der vil herliche gast
###### 927 | ### Do was gestruchet Hagne vor siner hant zetal ### von des slages krefte der wert vil lvte erhal ### er het sin swert enhende so wer ez Hagnen tot ### sere zurnde der wunde des <tvanch> in ehaftiv not
###### 928 | ### Erblichen was sin varwe er mohte niht gesten ### sines libes sterke mvoste gar cergen ### wand er des todes ceichen in liehter vrawe truoch ### sit wart er beweinet von schoenen vrowen genuoch
###### 929 | ### Do viel in die blvomen der Kiemhilde man ### daz bluot von sinen wunden sach man vaste gan ### do <begvnd> er schelden des twanch in groziv not ### die vf in geraten heten vngetriwe den tot
###### 930 | ### Do sprach der verkvnde ia ir bosen zagen ### waz helfent miniv dienst sid ir mich habet erslagen ### ich was iv ie getriwe des ich enkolten han ### ir habet an iwren frivnden leider vbele getan
###### 931 | ### Die sint da von bescholden swaz ir wirt geborn ### her nach disen citen ir habet iwern zorn ### gerochen al ze sere an dem libe min ### mit laster svlt gescheiden ir von guoten reken sin
###### 932 | ### Die riter alle liefen da er erslagen lac ### ez was ir genuogen ein vrovdeloser tac ### die iht triwe heten von den wart er gekleit ### daz hete ovch wol verdienet vmbe alle lûte der helt gemeit
###### 933 | ### Der kvnich von Burgonden klagte ovch sinen tot ### do sprach der verkvnde daz ist ane not [38b] ### daz der nach scaden weinet der in da hat getan ### der dient michel schelden ez were bezzer verlan
###### 934 | ### Do sprach der grimme Hagne ian weiz ich waz ir kleit ### ez hat nv allez ende an vns sorge vnde leit ### wir vinden ir nv wenich die geturren vns bestan ### wol mich daz ich des heldes han ze rate getan
###### 935 | ### Ir mvget ivch lihte ruemen sprach her Sifrit ### het ich an iv erkvnnet den mortlichen sit ### ich hete wol behalten vor iv minen lip ### mich riwet niht so sere so vrov Kriemhilt min wip
###### 936 | ### Nv muoze got erbarmen daz ich ie gewan den svn ### dem man itewizen sol daz hernach tuon ### daz sine mage ieman mortlich hant erslagen ### mohte ichz verenden daz sold ich billichen klagen
###### 937 | ### Do sprach iæmerliche der verchvnde man ### welt ir kvnich edel triwen iht began ### in der werlde an iemen so lat iv bevolhen sin ### vf iwer genade die lieben trutinne min
###### 938 | ### Lat si des geniesen daz si iwer swester si ### durch aller fursten tvgende wont ir mit triwen bi ### wan mir wartent lange min vater vnd min man ### ez wart nie leider an liebem vrivnde getan
###### 939 | ### Die bluomen allenthalben von bluote waren naz ### do rang er mit dem tode vnlange tet er daz ### wan des todes zeichen ie ze sere sneit ### sam muost ersterben ovch der reke kuone vnde gemeit
###### 940 | ### Do die heren sahen daz der helt was tot ### si leiten in vf einen schilt der was von golde rot ### vnde wurden des ze rate wie daz solde ergan ### daz man ez verhele daz ez Hagne hete getan
###### 941 | ### Do sprachen ir genuoge vns ist vbel geschehen ### ir svlt ez heln alle vnd svlt geliche iehen ### da er iagen rite aleine Kriemhilde man ### in sluogen sachere da er fuere durch den tan
###### 942 | ### Do sprach von Trony Hagne ich bring in in daz lant ### mir ist vil vnmere wirt ez ir bekant ### div so hat betruobet den Brunhilde mvot ### ez ahtet mich vil ringe swaz si nv weinens getuot

<<< Übersicht <<< vorige Seite nächste Seite >>>